from core.rpc.rpc import Caller, Server
from core.rpc.messagebus.caller import MessagebusCaller
from core.rpc.messagebus.server import MessagebusServer

assert Caller
assert Server
assert MessagebusCaller
assert MessagebusServer
